.. _cupy_reference:

****************
Reference Manual
****************

This is the official reference of CuPy, a multi-dimensional array on CUDA with a subset of NumPy interface.

* :ref:`genindex`
* :ref:`modindex`

----

.. currentmodule:: cupy

.. toctree::
   :maxdepth: 2

   ndarray
   ufunc
   routines
   scipy
   sparse
   ndimage
   generic
   memory
   cuda
   memoize
   kernel
   optimize
   interoperability
   testing
   prof
   environment
   difference
   comparison
   misc
